==> apache-tapestry-5.6.4-bin.zip: org/apache/tapestry5/internal/services/TypeCoercedValueEncoderFactory.java <==
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.apache.tapestry5.internal.services;

import org.apache.tapestry5.ValueEncoder;
import org.apache.tapestry5.ioc.internal.util.InternalUtils;
import org.apache.tapestry5.ioc.services.TypeCoercer;
import org.apache.tapestry5.services.ValueEncoderFactory;

/**
 * Provides {@link org.apache.tapestry5.ValueEncoder} instances that are backed by the {@link
 * org.apache.tapestry5.ioc.services.TypeCoercer} service.
 */
public class TypeCoercedValueEncoderFactory implements ValueEncoderFactory<Object>
{
    private final TypeCoercer typeCoercer;

    public TypeCoercedValueEncoderFactory(TypeCoercer typeCoercer)
    {
        this.typeCoercer = typeCoercer;
    }

    public ValueEncoder<Object> create(final Class<Object> type)
    {
        final boolean blankToNull =
                Boolean.class.isAssignableFrom(type) ||
                Number.class.isAssignableFrom(type);

        return new ValueEncoder<Object>()
        {
            public String toClient(Object value)
            {
                return typeCoercer.coerce(value, String.class);
            }

            public Object toValue(String clientValue)
            {
                if (blankToNull && InternalUtils.isBlank(clientValue)) {
                    return null;
                }

                return typeCoercer.coerce(clientValue, type);
            }
        };
    }
}

==> apache-tapestry-5.8.7-bin.zip: org/apache/tapestry5/internal/services/TypeCoercedValueEncoderFactory.java <==
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.apache.tapestry5.internal.services;

import org.apache.tapestry5.ValueEncoder;
import org.apache.tapestry5.commons.services.TypeCoercer;
import org.apache.tapestry5.ioc.internal.util.InternalUtils;
import org.apache.tapestry5.services.ValueEncoderFactory;

/**
 * Provides {@link org.apache.tapestry5.ValueEncoder} instances that are backed by the {@link
 * org.apache.tapestry5.commons.services.TypeCoercer} service.
 */
public class TypeCoercedValueEncoderFactory implements ValueEncoderFactory<Object>
{
    private final TypeCoercer typeCoercer;

    public TypeCoercedValueEncoderFactory(TypeCoercer typeCoercer)
    {
        this.typeCoercer = typeCoercer;
    }

    public ValueEncoder<Object> create(final Class<Object> type)
    {
        final boolean blankToNull =
                Boolean.class.isAssignableFrom(type) ||
                Number.class.isAssignableFrom(type);

        return new ValueEncoder<Object>()
        {
            public String toClient(Object value)
            {
                return typeCoercer.coerce(value, String.class);
            }

            public Object toValue(String clientValue)
            {
                if (blankToNull && InternalUtils.isBlank(clientValue)) {
                    return null;
                }

                return typeCoercer.coerce(clientValue, type);
            }
        };
    }
}
